###########################
awsfabrictasks
###########################

Fabric tasks for Amazon Web Services with some extra utilities for Ubuntu.


Issues/contribute
=================

Report any issues at the `github project page <awsfabrictasks>`_, and feel free
to add your own guides/experiences to the wiki, and to contribute changes using
pull requests.



.. _`awsfabrictasks`: https://github.com/espenak/awsfabrictasks
